#pragma once
#include <stdbool.h>

#define BOOTLOADER_EBG   "ebg"
#define BOOTLOADER_NONE  "none"
#define BOOTLOADER_GRUB  "grub"
#define BOOTLOADER_UBOOT "uboot"
#define BOOTLOADER_CBOOT "cboot"

#define load_symbol(handle, container, fname) \
	*(void**)(container) = dlsym(handle, fname); \
	if (dlerror() != NULL) { \
		(void)dlclose(handle); \
		return NULL; \
	}

typedef struct {
	int (*env_set)(const char *, const char *);
	int (*env_unset)(const char *);
	char* (*env_get)(const char *);
	int (*apply_list)(const char *);
} bootloader;

int register_bootloader(const char *name, bootloader *bl);
int set_bootloader(const char *name);
const char* get_bootloader(void);
bool is_bootloader(const char *name);
void print_registered_bootloaders(void);
extern int (*bootloader_env_set)(const char *, const char *);
extern int (*bootloader_env_unset)(const char *);
extern char* (*bootloader_env_get)(const char *);
extern int (*bootloader_apply_list)(const char *);

